@@ -132,7 +132,11 @@ class Protobuf:
         content = content + '\n'
         if self.config.preview:
             self.print_with_color()
-        return content
+        content_from_text_list = self.from_text_list()  # using formatted content build from text list.
+        content_from_text_list = content_from_text_list.rstrip("\n")  # removed the two new lines("\n")
+        content_from_text_list = content_from_text_list + "\n"  # append one new line("\n"), to keep the same as content
+
+        return content  # content_from_text_list
 
     def print_with_color(self):
         print()
@@ -140,6 +144,14 @@ class Protobuf:
             text.color_print()
         print()
 
+    def from_text_list(self):
+        content = ""
+        for text in self.text_list:
+            if isinstance(text, Text):
+                debug = 0
+            content = content + text.text
+        return content
+
     def flatten_objects(self):
         new_objects = []
 
@@ -373,6 +385,7 @@ class Protobuf:
     def create_object_rear(self, obj, indents):
         bottom_comments = [comment for comment in obj.comments if comment.position == Position.BOTTOM]
         color_text_list = [
+            Text(self.config.ONE_SPACE * indents, ColorConfig.default.value),
             Text("}", ColorConfig.default.value)
         ]
 
@@ -644,7 +657,6 @@ class Protobuf:
             line = f'{value_line}{self.config.ONE_SPACE * space_between_number_comment}// {right_comment}'
             lines.append(line)
             color_comment_text_list = [
-                Text(self.config.ONE_SPACE * indents, ColorConfig.default.value),
                 Text(self.config.ONE_SPACE * space_between_number_comment, ColorConfig.default.value),
                 Text("//", ColorConfig.comment.value),
                 Text(" ", ColorConfig.default.value),
@@ -655,7 +667,7 @@ class Protobuf:
             self.text_list.extend(color_text_list)
         else:
             lines.append(value_line)
-            color_text_list.insert(0, Text(self.config.ONE_SPACE * indents, ColorConfig.default.value))
+            # color_text_list.insert(0, Text(self.config.ONE_SPACE * indents, ColorConfig.default.value))
             color_text_list.append(Text("\n", ColorConfig.default.value))
 
             self.text_list.extend(color_text_list)
@@ -734,7 +746,7 @@ class Protobuf:
         convert right comment to comment lines:
         (1) keep top comments. If the comment_max_length flag is set and the length of one original line exceeds it,
             this line will be converted to multiple lines.
-        (2) convert right comment to multiple lines, append it to top comments lines.
+        (2) convert right comment to multiple lines.
         (3) convert bottom comments(the comments under the last element or follow the message etc.) to multiple lines.
             If the comment_max_length flag is set and the length of one original line exceeds it, this line will be
             converted to multiple lines. This lines will not be appended to top comments lines.
